aboutsummaryrefslogtreecommitdiff
path: root/libcons/vcons-add.c
diff options
context:
space:
mode:
Diffstat (limited to 'libcons/vcons-add.c')
-rw-r--r--libcons/vcons-add.c17
1 files changed, 2 insertions, 15 deletions
diff --git a/libcons/vcons-add.c b/libcons/vcons-add.c
index cc7717f6..1a6eb204 100644
--- a/libcons/vcons-add.c
+++ b/libcons/vcons-add.c
@@ -22,22 +22,9 @@
#include "cons.h"
/* The virtual console VCONS was just added. VCONS->cons is
locked. */
void
-cons_vcons_add (vcons_t vcons)
+cons_vcons_add (cons_t cons, vcons_list_t vcons_entry)
{
- error_t err;
-
- /* The first console added will be activated automatically. */
- if (vcons->cons->active)
- return;
-
- /* Forward the activation request to the user. */
- err = cons_vcons_activate (vcons);
- if (!err)
- {
- vcons->cons->active = vcons;
- cons_vcons_refresh (vcons);
- }
}
@@ -22,22 +22,9 @@
#include "cons.h"
-/* The virtual console VCONS was just added. VCONS->cons is
+/* The virtual console entry VCONS_ENTRY was just added. CONS is
locked. */
void